# Textual Key Recorder

A tool to help record what keys result in what names in a Textual
application.

## Installation

This tool can be installed from PyPi; ideally using `pipx`:

```sh
$ pipx install textual-key-recorder
```

Once installed, you can run it as `tkrec`.

## Usage

This is mainly used for my own testing and exploring for now; but if you
find it interesting follow your nose; and if you're really interested drop
by the [Textualize help resources and have a chat with
us](https://textual.textualize.io/help/).
